/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEMODULECOREPROCESS_H
#define SEMODULECOREPROCESS_H

#include <QDialog>
#include <QLayout>
#include <QDir> 
#include <QLabel> 
#include <QTextEdit>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QProcess> 


class QLayout;
class QTextEdit;
class QLineEdit;
class QPushButton;

class SemoduleCoreProcess: public QDialog 
{
	Q_OBJECT
public:
	SemoduleCoreProcess(QWidget *parent = 0, const char *name = 0);
	int i;
	QString outputfile_str_common;
	QString outputfile_str_common2;
	QString textEdit1_str;
public slots:
	void semodule_core_base_process();
signals:
protected:
private slots:
	void make_button_clicked();
	void install_button_clicked();
	void update_button_clicked();
	void remove_button_clicked();
	void make_button_clicked_process(QString textEdit1_str);
	void install_button_clicked_process(QString textEdit1_str);
	void update_button_clicked_process(QString textEdit1_str);
	void remove_button_clicked_process(QString textEdit1_str);
	//void readFromOutputFile();
	//void readFromOutputFile2();
//newly added
	void readFromStdoutB();
	void updateOutputTextEditB();
        void processExitedB(int, QProcess::ExitStatus);
	void readFromStdout();
	void updateOutputTextEdit();
        void processExited(int, QProcess::ExitStatus);
//end newly added
public:
private:
//newly added
	QProcess *processB;
	QProcess *process;
//end newly added
	QPushButton *makeButton;
	QPushButton *installButton;
	QPushButton *updateButton;
	QPushButton *removeButton;
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	QTextEdit *textEdit2;

	QHBoxLayout *mainLayout;
	QVBoxLayout *leftLayout;
	QVBoxLayout *middleLayout;
	QVBoxLayout *rightLayout;
	QVBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *moduleEditLabel;
        QLineEdit *moduleEditLineEdit;
        QString moduleEditLineEdit_str;
        QString moduleEditLineEdit_str_pp;
};

#endif
